MeasurementMode

Enum MeasurementMode 

pub enum MeasurementMode {
    Idle,
    ConstantPower1s,
    PulseHeating10s,
    LowPowerPulseHeating60s,
    ConstantPower250ms,
}
Measurement modes.

NOTE: When changing to a new mode with a lower sample rate, place the device in Idle mode for at least 10 minutes before enabling the new mode.

Variants



Idle

Idle. Measurements are disabled. (Mode 0)



ConstantPower1s

Constant power mode. IAQ measurement every second. (Mode 1)



PulseHeating10s

Pulse heating mode. IAQ measurement every 10 seconds. (Mode 2)



LowPowerPulseHeating60s

Low power pulse heating mode. IAQ measurement every 60 seconds. (Mode 3)



ConstantPower250ms

Constant power mode. IAQ measurement every 250ms. (Mode 4)